/*
 * Copyright (C) Christof Musik, bitbone AG
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef GRAPH_H
#define GRAPH_H
#include <qwidget.h>
#include <qvaluevector.h>
#include <qpointarray.h> 
#include <qcolor.h>
#include <qtimer.h>
#include <qfont.h>
#include <qdatetime.h>

class Graph : public QWidget{
    Q_OBJECT

    public:
	Graph(QWidget *parent=0, const char * name=0, WFlags flags=0);
	~Graph(void);
	void paintEvent(QPaintEvent *);
	void mouseReleaseEvent(QMouseEvent *);
	void resizeEvent(QResizeEvent *);
	bool put(QString);
	bool put(QString, QString);
	void setTimeout(int);
	void setConnectedServer(QString);
	int getValue(int);
	QColor getBackgroundColor(void);
	QColor getForegroundColor(void);
	QColor getGraphColor(void);
	void setBackgroundColor(QColor);
	void setForegroundColor(QColor);
	void setGraphColor(QColor);
	void setNamedOID(QString);
	void setShowLines(bool);
	bool getShowLines(void);
	void setGraphFont(QFont);
	void setType(int);
	int getType(void);
	void setShowTimeline(bool);
	bool getShowTimeline(void);
	QFont getGraphFont(void);
	void setUnitType(int);
	void setFixedMaximum(int);
	void setShowToplabel(bool);
	bool getShowToplabel();

	enum Type {
	    Lines = 1,
	    Polygon = 2,
	    Outline = 3,
	    TypeCounter = 3
	};

	enum Unit {
	    None = 10,
	    Bytes = 0,
	    KBytes = 1,
	    MBytes = 2,
	    GBytes = 3,
	    Percent = 100,
	};
    
    private:
	void checkNewMaximum(void);
	QPointArray getPoints(void);
	void checkDataUnitFactor(void);

	QValueVector<int> * snmpvalues;
	QTimer *valueTimer;
	double old_counter_value;
	int max_value;
	QString old_oid;
	QString old_type;
	QString svalues;
	int timeout;
	QColor background;
	QColor foreground;
	QColor graphcolor;
	QFont font;
	QString connected_server;
	QString named_oid;
	bool showLines;
	bool showValue;
	bool showTimeline;
	bool fixedMaximum;
	int clickValue;
	QPoint clickPos;
	int type;
	int unittype;
	int unitfactor;
	QString unitstring;
	bool toplabel;
	int alarm_max_value;
	int alarm_min_value;
	
    public slots:
        void removeMax(void);
	void cleanUp(void);
	void switchType(void);
	void showInlineValue(void);

    private slots:
	void hideInlineValue(void);
	
    signals:
	void clicked(int);
	//void alarmMax();
	//void alarmMin();
};
#endif
