/*
 * Copyright (C) Christof Musik, bitbone AG
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <iostream>
#include <qapplication.h>
#include <qdir.h>
#include <qtextcodec.h>
#include <qcombobox.h>

#include "config.h"
#include "snmpmon.h"

void printHelp() {
    std::cout << QObject::tr("Usage: snmpmon [ -f | -s | -c | -v | -w | -sw | -sh | -o | -t ] ") << std::endl;
    std::cout << QObject::tr("-f, --file <filename>")		<< "\t\t" << QObject::tr("Open this Monitoringfile") << std::endl;
    std::cout << QObject::tr("-s, --server <name>")		<< "\t\t" << QObject::tr("Connect to this server") << std::endl;
    std::cout << QObject::tr("-c, --community <name>")		<< "\t\t" << QObject::tr("Set community") << std::endl;
    std::cout << QObject::tr("-v, --protocolversion <version>") << "\t" << QObject::tr("Set the protocol version") << std::endl;
    std::cout << QObject::tr("-w, --withdrawn")			<< "\t\t\t" << QObject::tr("Set widthdrawn state") << std::endl;
    std::cout << QObject::tr("-sw, --width <value>")		<< "\t\t" << QObject::tr("Sets the width, works only with -s") << std::endl;
    std::cout << QObject::tr("-sh, --height <value>")		<< "\t\t" << QObject::tr("Sets the height, works only with -s") << std::endl;
    std::cout << QObject::tr("-o, --oid <oidname>")		<< "\t\t" << QObject::tr("Sets the oid, works only with -s") << std::endl;
    std::cout << QObject::tr("-t, --titlebar")			<< "\t\t\t" << QObject::tr("Hides the titlebar") << std::endl;
}

int main( int argc, char ** argv )
{
    QApplication a( argc, argv );
    QDir dir(QDir::homeDirPath()+"/.snmpmon");
    if (!dir.exists()) dir.mkdir(QDir::homeDirPath()+"/.snmpmon");

    QTranslator snmptrans( 0 );
    snmptrans.load( QString("/usr/share/snmpmon/snmpmon_")+QTextCodec::locale(), "." );
    a.installTranslator( &snmptrans );
    QTranslator qt( 0 );
    qt.load( QString("/usr/share/qt3/translations/qt_")+QTextCodec::locale(), ".");
    a.installTranslator( &qt );
    
    SNMPMonitor w;

    QString srv = "";
    QString com = COMMUNITY;
    int ver = PROTOCOL_VERSION;
    bool readprefs = true;
    bool openmonfile = false;
    for (int i = 1; i < a.argc(); i++) {
	if (QString(a.argv()[i]) == "--help" || QString(a.argv()[i]) == "-h" || QString(a.argv()[i]) == "-help") {
	    printHelp();
	    exit (0);
	}
	else if (QString(a.argv()[i]) == "--community" || QString(a.argv()[i]) == "-c") {
	    com = QString(a.argv()[++i]);
	}
	else if (QString(a.argv()[i]) == "--server" || QString(a.argv()[i]) == "-s") {
	    srv = QString(a.argv()[++i]);
	}
	else if (QString(a.argv()[i]) == "--protocolversion" || QString(a.argv()[i]) == "-v") {
	    ver = QString(a.argv()[++i]).toInt();
	}
	else if ( QString(a.argv()[i]) == "--file" || QString(a.argv()[i]) == "-f" ) {
	    if (QFileInfo(QString(a.argv()[i+1])).isReadable()) {
		w.readMonitorFile(a.argv()[i+1]);
		openmonfile = true;
		break;
	    }
	    else {
	    	std::cerr << QObject::tr("ERROR: File not specified or not readable!") << std::endl << std::endl;
		printHelp();
		exit(0);
	    }
	    break;
	}
	else if ( QString(a.argv()[i]) == "--withdrawn" || QString(a.argv()[i]) == "-w" ) {
	    w.setWithdrawnState();
	}
	else if ( QString(a.argv()[i]) == "--width" || QString(a.argv()[i]) == "-sw" ) {
	    i++;
	    w.setWidth( QString( a.argv()[i] ).toInt() );
	    readprefs = false;
	}
	else if ( QString(a.argv()[i]) == "--height" || QString(a.argv()[i]) == "-sh" ) {
	    i++;
	    w.setHeight( QString( a.argv()[i] ).toInt() );
	    readprefs = false;
	}
	else if ( QString(a.argv()[i]) == "--oid" || QString(a.argv()[i]) == "-o" ) {
	    i++;
	    for (int k = 0; k < w.oidinput->count(); k++) {
		if ( w.oidinput->text(k) == QString(a.argv()[i]) ) {
		    w.oidinput->setCurrentItem(k);
		    break;
		}
	    }
	    readprefs = false;
	}
	else if ( QString(a.argv()[i]) == "--titlebar" || QString(a.argv()[i]) == "-t" ) {
	    w.showborder(false);
	    readprefs = false;
	}
	else {
	    std::cout << QObject::tr("ERROR: wrong commandline options!") << std::endl << std::endl;
	    printHelp();
	    exit(0);
	}
    }
    if (!openmonfile) {
	if (srv != "") {
	    w.setServer(srv, com, ver, true, readprefs);
	}
	else
	    w.connectto(true);

	w.show();
    }
    
    a.connect( &a, SIGNAL( lastWindowClosed() ), &a, SLOT( quit() ) );
    return a.exec();
}
