/*
 * Copyright (C) Christof Musik, bitbone AG
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#include "graph.h"
#include <iostream>
#include <qmessagebox.h>
#include <snmptalker.h>
#include <qstring.h>
#include <qstringlist.h>

void oidmapeditor::addslot()
{
    if ( (nameinput->text() != "") && (oidinput->text() != "") ) {
	QListViewItemIterator it(oidmapview);
	bool check = true;
	while (it.current()) {
	    QListViewItem *item = it.current();
	    if ( item->text(0) == nameinput->text() ) {
		check = false;
		int button = QMessageBox::warning (this, 
			tr("Name already exits!"),
			tr("Would you like to overwrite '%1'?").arg( nameinput->text() ),
			QMessageBox::Yes,
			QMessageBox::No
			);

		if (button == QMessageBox::Yes) {
		    oidmapview->takeItem(item);
		    check = true;
		}
		break;
	    }
	    it++;
	}

	QStringList oid_list = QStringList::split("+", oidinput->text());

	for ( QStringList::Iterator it = oid_list.begin(); it != oid_list.end(); ++it ) {
	    char* o = strdup( QString(*it).latin1() );
	    if ( !SNMPTalker::checkOID( o ) ) {
		// OID is not valid
		check = false;
		QMessageBox::warning ( this, tr("OID not valid"), tr("The OID '%1' is not valid!").arg(*it), QMessageBox::Ok, 0 );
	    }
	free(o);
	}

	if (check) {
	    QString text = cbUnit->currentText();
	    if (text == tr("None")) text = "-";
	    
	    new QListViewItem(oidmapview, nameinput->text(), oidinput->text(), text);
	    nameinput->clear();
	    oidinput->clear();
	    cbUnit->setCurrentItem(0);
	}
    }
}


void oidmapeditor::deleteslot()
{
    QListViewItem *item = oidmapview->selectedItem();
    int button = QMessageBox::question ( this,
	    tr("Delete ..."),
	    tr("Do you really want to delete '%1'?").arg( item->text(0) ),
	    QMessageBox::Yes,
	    QMessageBox::No
	    );
    if (button == QMessageBox::Yes)
	oidmapview->takeItem(oidmapview->selectedItem());
}


void oidmapeditor::initMap(QString filename, QString str)
{
    map->openFile(filename);

    host = str;
    QString oidfile = QDir::homeDirPath()+"/.snmpmon/oid.map."+str;

    if ( QFileInfo( oidfile ).isReadable() && QFileInfo( oidfile ).isWritable() ) {
	cbSaveAs->setText( tr("Save for %1").arg("default") );
	setCaption( tr("OID Map Editor - %1").arg(host) );
	host = str;
	host_alternate = "";
    } else {
	cbSaveAs->setText( tr("Save for %1").arg(str) );
	setCaption( tr("OID Map Editor - %1").arg("default") );
	host = "";
	host_alternate = str;
    }

    QMap<QString,QString> omap = map->getMapOID();
    QMap<QString,int> unitmap = map->getMapUnit();
    QMap<QString,QString>::iterator it;
    checkAddBtn();
    checkBtn();
    for (it = omap.begin(); it != omap.end(); it++) {
	new QListViewItem(oidmapview, it.key(), it.data(), getUnitName(unitmap[it.key()]));
    }
    oidmapview->setColumnWidthMode(0, QListView::Maximum);
    oidmapview->setColumnWidthMode(1, QListView::Manual);
    oidmapview->setColumnWidthMode(2, QListView::Maximum);
    oidmapview->setColumnWidth(1, 400);
}


void oidmapeditor::editslot()
{
    QListViewItem *item = oidmapview->selectedItem();
    if (item != NULL) {
	int button = 0;
	if (nameinput->text() != "" && oidinput->text() != "") {
	    button = QMessageBox::question(this, tr("Overwrite ...?"), tr("Do you want to overwrite this Item?"), QMessageBox::Yes, QMessageBox::No);
	}
	if ( button == 0 || button == QMessageBox::Yes ) {
	    nameinput->setText(item->text(0));
	    oidinput->setText(item->text(1));

	    QString text = item->text(2);
	    if (text == "-") text = tr("None");
	    // select item in cbUnit
	    for (int i = 0; i < cbUnit->count(); i++) {
		if (cbUnit->text(i) == tr(text)) {
		    cbUnit->setCurrentItem(i);
		    break;
		}
	    }
	    oidmapview->takeItem( oidmapview->selectedItem() );
	}
    }
}

QMap<QString,QString> oidmapeditor::getOIDItems()
{
    QMap<QString,QString> qmap;
    QListViewItemIterator it(oidmapview);

    while (it.current()) {
	QListViewItem *item = it.current();
	qmap[item->text(0)] = item->text(1);
	it++;
    }

    return qmap;
}

QMap<QString,int> oidmapeditor::getUnitItems()
{
    QMap<QString,int> qmap;
    QListViewItemIterator it(oidmapview);

    while (it.current()) {
	QListViewItem *item = it.current();
	qmap[item->text(0)] = getUnitID(item->text(2));
	it++;
    }

    return qmap;
}

void oidmapeditor::checkAddBtn()
{
    if ( (nameinput->text() != "") && (oidinput->text() != "") ) {
	addbtn->setEnabled(true);
    } else {
	addbtn->setEnabled(false);
    }
}

void oidmapeditor::checkBtn()
{
    if (oidmapview->selectedItem() == NULL) {
	editbtn->setEnabled(false);
	deletebtn->setEnabled(false);
    } else {
	editbtn->setEnabled(true);
	deletebtn->setEnabled(true);
    }
}

void oidmapeditor::init()
{
    map = new OIDMap();
    host = QString::null;
}

QString oidmapeditor::getUnitName(int id) {
    QString unit;
    switch (id) {
	case Graph::Bytes: 
	    unit = tr("Bytes");
	    break;
	case Graph::KBytes: 
	    unit = tr("KBytes");
	    break;
	case Graph::MBytes: 
	    unit = tr("MBytes");
	    break;
	case Graph::GBytes: 
	    unit = tr("GBytes");
	    break;
	case Graph::Percent: 
	    unit = tr("%");
	    break;

	default: 
	    unit = tr("-");
    }
    return unit;
}

int oidmapeditor::getUnitID(QString str) {
    int id = Graph::None;
    if (str == tr("Bytes")) id = Graph::Bytes;
    if (str == tr("KBytes")) id = Graph::KBytes;
    if (str == tr("MBytes")) id = Graph::MBytes;
    if (str == tr("GBytes")) id = Graph::GBytes;
    if (str == tr("%")) id = Graph::Percent;

    return id;
}

QString oidmapeditor::getHost() {
    if (!cbSaveAs->isChecked())
	return host;
    else
	return host_alternate;
}
